@@ -255,7 +255,7 @@ impl Decoder for i64 {
     where
         T: Buf,
     {
-        if src.remaining() < 4 {
+        if src.remaining() < 8 {
             return Err(Error::new(ErrorKind::UnexpectedEof, "can't read i64"));
         }
         let value = src.get_i64();
@@ -613,7 +613,7 @@ mod test {
         let mut value: bool = false;
         let result = value.decode(&mut Cursor::new(&data), 0);
         assert!(result.is_ok());
-        assert_eq!(value, true);
+        assert!(value);
     }
 
     #[test]
